==> Pouches-1.1.0-sources.jar: fun/wich/PouchItem.java <==
package fun.wich;

import net.minecraft.block.*;
import net.minecraft.class_11362;
import net.minecraft.class_11580;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1621;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1928;
import net.minecraft.class_2487;
import net.minecraft.class_3218;
import net.minecraft.class_8942;
import net.minecraft.class_9279;
import net.minecraft.class_9334;
import net.minecraft.entity.*;
import net.minecraft.item.*;
import java.util.Optional;

public class PouchItem extends class_1792 {
	public PouchItem(class_1793 settings) { super(settings); }
	public class_1799 getEmptiedStack(class_1799 stack, class_1657 player) {
		return !player.method_56992() ? new class_1799(Pouches.POUCH) : stack;
	}
	@Override
	public class_1269 method_7847(class_1799 stack, class_1657 player, class_1309 livingEntity, class_1268 hand) {
		return tryPouch(player, hand, livingEntity).orElse(super.method_7847(stack, player, livingEntity, hand));
	}
	protected static Optional<class_1269> tryPouch(class_1657 player, class_1268 hand, class_1309 entity) {
		class_1799 stack = player.method_5998(hand);
		if (player.method_73183() instanceof class_3218 serverWorld) {
			if (!(entity instanceof class_1657)) {
				class_1928 rules = serverWorld.method_64395();
				if (rules.method_8355(Pouches.ALLOW_POUCHING_ALL) //Allow pouching all entities
						|| (rules.method_8355(Pouches.ALLOW_POUCHING_BABY) //Allow babies whether tagged or not
							&& (entity.method_6109() || (entity instanceof class_1621 slime && slime.method_7152() <= 1)))
						|| entity.method_5864().method_20210(Pouches.TAG_POUCHABLE)) { //Limit to tagged entity types
					if (stack.method_7909() == Pouches.POUCH && entity.method_5805()) {
						entity.method_5783(Pouches.ITEM_POUCH_FILL, 1.0F, 1.0F);
						class_1799 itemStack2 = new class_1799(Pouches.FILLED_POUCH);
						entity.method_29239();
						entity.method_5772();
						copyDataToStack(entity, itemStack2);
						if (player.method_56992()) {
							if (!player.method_31548().method_7379(itemStack2)) player.method_31548().method_7394(itemStack2);
						}
						else if (stack.method_7947() > 1) {
							stack.method_7934(1);
							player.method_31548().method_7394(itemStack2);
						}
						else player.method_6122(hand, itemStack2);
						entity.method_31472();
						return Optional.of(class_1269.field_5812);
					}
				}
			}
		}
		return Optional.empty();
	}

	protected static void copyDataToStack(class_1309 entity, class_1799 stack) {
		try (class_8942.class_11340 logging = new class_8942.class_11340(entity.method_71370(), Pouches.LOGGER)) {
			class_11362 nbtWriteView = class_11362.method_71459(logging, entity.method_56673());
			entity.method_5662(nbtWriteView);
			stack.method_57379(class_9334.field_49609, class_11580.method_72535(entity.method_5864(), nbtWriteView.method_71475()));
			class_2487 nbt = new class_2487();
			nbt.method_10556("IsBaby", entity.method_6109());
			stack.method_57379(class_9334.field_49628, class_9279.method_57456(nbt));
		}
	}
}

==> Pouches-1.3.0-sources.jar: fun/wich/PouchItem.java <==
package fun.wich;

import net.minecraft.block.*;
import net.minecraft.class_11362;
import net.minecraft.class_11580;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1309;
import net.minecraft.class_1621;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1928;
import net.minecraft.class_2487;
import net.minecraft.class_3218;
import net.minecraft.class_5761;
import net.minecraft.class_8942;
import net.minecraft.class_9279;
import net.minecraft.class_9334;
import net.minecraft.entity.*;
import net.minecraft.item.*;
import java.util.Optional;

public class PouchItem extends class_1792 {
	public PouchItem(class_1793 settings) { super(settings); }
	public class_1799 getEmptiedStack(class_1799 stack, class_1657 player) {
		return !player.method_56992() ? new class_1799(Pouches.POUCH) : stack;
	}
	@Override
	public class_1269 method_7847(class_1799 stack, class_1657 player, class_1309 livingEntity, class_1268 hand) {
		return tryPouch(player, hand, livingEntity).orElse(super.method_7847(stack, player, livingEntity, hand));
	}
	protected static Optional<class_1269> tryPouch(class_1657 player, class_1268 hand, class_1309 entity) {
		class_1799 stack = player.method_5998(hand);
		if (player.method_73183() instanceof class_3218 serverWorld) {
			if (!(entity instanceof class_1657)) {
				class_1928 rules = serverWorld.method_64395();
				if (rules.method_8355(Pouches.ALLOW_POUCHING_ALL) //Allow pouching all entities
						|| (rules.method_8355(Pouches.ALLOW_POUCHING_BABY) //Allow babies whether tagged or not
							&& (entity.method_6109() || (entity instanceof class_1621 slime && slime.method_7152() <= 1)))
						|| entity.method_5864().method_20210(Pouches.TAG_POUCHABLE)) { //Limit to tagged entity types
					if (stack.method_7909() == Pouches.POUCH && entity.method_5805()) {
						entity.method_5783(Pouches.ITEM_POUCH_FILL, 1.0F, 1.0F);
						class_1799 itemStack2 = new class_1799(Pouches.FILLED_POUCH);
						entity.method_29239();
						entity.method_5772();
						copyDataToStack(entity, itemStack2);
						if (player.method_56992()) {
							if (!player.method_31548().method_7379(itemStack2)) player.method_31548().method_7394(itemStack2);
						}
						else if (stack.method_7947() > 1) {
							stack.method_7934(1);
							player.method_31548().method_7394(itemStack2);
						}
						else player.method_6122(hand, itemStack2);
						entity.method_31472();
						return Optional.of(class_1269.field_5812);
					}
				}
			}
		}
		return Optional.empty();
	}

	protected static void copyDataToStack(class_1309 entity, class_1799 stack) {
		try (class_8942.class_11340 logging = new class_8942.class_11340(entity.method_71370(), Pouches.LOGGER)) {
			class_11362 nbtWriteView = class_11362.method_71459(logging, entity.method_56673());
			entity.method_5662(nbtWriteView);
			stack.method_57379(class_9334.field_49609, class_11580.method_72535(entity.method_5864(), nbtWriteView.method_71475()));
			class_2487 nbt = new class_2487();
			nbt.method_10556("IsBaby", entity.method_6109());
			stack.method_57379(class_9334.field_49628, class_9279.method_57456(nbt));
			if (entity instanceof class_5761 bucketable) bucketable.method_6455(stack);
		}
	}
}
